/*
 * Electric(tm) VLSI Design System
 *
 * File: usrdiacom.h
 * Special command dialogs, headers
 * Written by: Steven M. Rubin, Static Free Software
 *
 * Copyright (c) 2000 Static Free Software.
 *
 * Electric(tm) is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Electric(tm) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Electric(tm); see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, Mass 02111-1307, USA.
 *
 * Static Free Software
 * 4119 Alpine Road
 * Portola Valley, California 94028
 * info@staticfreesoft.com
 */

#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
extern "C"
{
#endif

INTSML us_3ddepthdlog();
INTSML us_aboutdlog(void);
INTSML us_alignmentdlog(void);
INTSML us_annularringdlog(void);
INTSML us_arcsizedlog(char*[]);
INTSML us_areadlog(char*, char*[], char*);
INTSML us_arraydlog(char*[]);
INTSML us_artlookdlog(void);
INTSML us_attributesdlog(void);
INTSML us_capacitancedlog(char*[], char*);
INTSML us_colormixdlog(char *overlayernames[]);
INTSML us_copyfacetdlog(char*);
INTSML us_createtodlog(char*[]);
INTSML us_defarcdlog(void);
INTSML us_defnodedlog(void);
INTSML us_deftextdlog(char*);
INTSML us_dependentlibdlog(void);
INTSML us_editfacetdlog(char*);
INTSML us_facetdlog(void);
INTSML us_facetlist(char*, char*[], INTSML);
INTSML us_filedlog(COMCOMP*, char*[], char*, INTSML);
INTSML us_findtextdlog(void);
INTSML us_frameoptionsdlog(void);
INTSML us_gaindlog(char*, char*[], char*);
INTSML us_griddlog(void);
INTSML us_helpdlog(char*);
INTSML us_highlayerlog(void);
INTSML us_iconstyledlog(void);
INTSML us_inductancedlog(char*[], char*);
INTSML us_lambdadlog(void);
INTSML us_librarypathdlog(void);
INTSML us_libtotechnologydlog(void);
INTSML us_menudlog(char*[]);
INTSML us_modtextsizedlog(void);
INTSML us_newfacetdlog(char*[]);
INTSML us_newviewdlog(char*[]);
INTSML us_nodesizedlog(char*[]);
INTSML us_noyesalwaysdlog(char*, char*[]);
INTSML us_noyesdlog(char*, char*[]);
INTSML us_oldlibrarydlog(void);
INTSML us_optionsavingdlog(void);
INTSML us_patterndlog(void);
INTSML us_placetextdlog(void);
INTSML us_plotoptionsdlog(void);
INTSML us_portdisplaydlog(void);
INTSML us_portdlog(char*[]);
INTSML us_purelayernodedlog(char*[]);
INTSML us_quickkeydlog(void);
INTSML us_quitdlog(char*, char*[]);
INTSML us_renamedlog(void);
INTSML us_replacedlog(void);
INTSML us_resistancedlog(char*, char*[], char*);
INTSML us_selectoptdlog(void);
INTSML us_selectportnodenetdlog(INTSML);
INTSML us_showdlog(INTSML);
INTSML us_sourcedlog(char*[], NODEINST*, VARIABLE*);
INTSML us_spreaddlog(void);
INTSML us_technologydlog(char*, char*[]);
INTSML us_techoptdlog(void);
INTSML us_techvarsdlog(void);
INTSML us_tracedlog(void);
INTSML us_variablesdlog(void);
INTSML us_vccsdlog(char*[], char*);
INTSML us_viewdlog(INTBIG);
INTSML us_visiblelayersdlog(char*);
INTSML us_widlendlog(char*[], char*);
INTSML us_windowviewdlog(void);
INTSML us_yesnodlog(char*, char*[]);

#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
}
#endif
